@@ -27,30 +27,40 @@ data_arrange <- function(data, select = NULL, safe = TRUE) {
 }
 
 
-
 #' @export
 data_arrange.default <- function(data, select = NULL, safe = TRUE) {
   if (is.null(select) || length(select) == 0) {
     return(data)
   }
 
+  original_x <- data
+
   # Input validation check
   data <- .coerce_to_dataframe(data)
 
+  # Remove tidyverse attributes, will add them back at the end
+  if (inherits(original_x, "tbl_df")) {
+    tbl_input <- TRUE
+    data <- as.data.frame(data, stringsAsFactors = FALSE)
+  } else {
+    tbl_input <- FALSE
+  }
+
   # find which vars should be decreasing
   desc <- select[startsWith(select, "-")]
   desc <- gsub("^-", "", desc)
   select <- gsub("^-", "", select)
 
   # check for variables that are not in data
-  dont_exist <- select[which(!select %in% names(data))]
+  dont_exist <- setdiff(select, colnames(data))
 
   if (length(dont_exist) > 0) {
     if (safe) {
       insight::format_warning(
         paste0(
           "The following column(s) don't exist in the dataset: ",
-          text_concatenate(dont_exist), "."
+          text_concatenate(dont_exist),
+          "."
         ),
         .misspelled_string(names(data), dont_exist, "Possibly misspelled?")
       )
@@ -58,7 +68,8 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
       insight::format_error(
         paste0(
           "The following column(s) don't exist in the dataset: ",
-          text_concatenate(dont_exist), "."
+          text_concatenate(dont_exist),
+          "."
         ),
         .misspelled_string(names(data), dont_exist, "Possibly misspelled?")
       )
@@ -70,7 +81,11 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
     return(data)
   }
 
-  already_sorted <- all(vapply(data[, select, drop = FALSE], .is_sorted, logical(1L)))
+  already_sorted <- all(vapply(
+    data[, select, drop = FALSE],
+    .is_sorted,
+    logical(1L)
+  ))
 
   if (isTRUE(already_sorted)) {
     return(data)
@@ -87,25 +102,36 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
 
   # apply ordering
   if (length(select) == 1) {
-    out <- data[order(out[[select]]), ]
+    out <- data[order(out[[select]]), , drop = FALSE]
   } else {
-    out <- data[do.call(order, out[, select]), ]
+    out <- data[do.call(order, out[, select]), , drop = FALSE]
   }
 
   if (!insight::object_has_rownames(data)) {
     rownames(out) <- NULL
   }
 
+  # add back custom attributes
+  out <- .replace_attrs(out, attributes(original_x))
+
   out
 }
 
 
-
 #' @export
 data_arrange.grouped_df <- function(data, select = NULL, safe = TRUE) {
+  original_x <- data
   grps <- attr(data, "groups", exact = TRUE)
   grps <- grps[[".rows"]]
 
+  # Remove tidyverse attributes, will add them back at the end
+  if (inherits(data, "tbl_df")) {
+    tbl_input <- TRUE
+    data <- as.data.frame(data, stringsAsFactors = FALSE)
+  } else {
+    tbl_input <- FALSE
+  }
+
   out <- lapply(grps, function(x) {
     data_arrange.default(data[x, ], select = select, safe = safe)
   })
@@ -116,5 +142,13 @@ data_arrange.grouped_df <- function(data, select = NULL, safe = TRUE) {
     rownames(out) <- NULL
   }
 
+  # add back tidyverse attributes
+  if (isTRUE(tbl_input)) {
+    class(out) <- c("tbl_df", "tbl", "data.frame")
+  }
+
+  # add back custom attributes
+  out <- .replace_attrs(out, attributes(original_x))
+
   out
 }
