@@ -20,65 +20,63 @@
 #' @return
 #' A merged data frame.
 #'
-#' @details
+#' @section Merging data frames:
 #'
-#'   \subsection{Merging data frames}{
-#'     Merging data frames is performed by adding rows (cases), columns
-#'     (variables) or both from the source data frame (`y`) to the target
-#'     data frame (`x`). This usually requires one or more variables which
-#'     are included in both data frames and that are used for merging, typically
-#'     indicated with the `by` argument. When `by` contains a variable present
-#'     in both data frames, cases are matched and filtered by identical values
-#'     of `by` in `x` and `y`.
-#'   }
+#' Merging data frames is performed by adding rows (cases), columns
+#' (variables) or both from the source data frame (`y`) to the target
+#' data frame (`x`). This usually requires one or more variables which
+#' are included in both data frames and that are used for merging, typically
+#' indicated with the `by` argument. When `by` contains a variable present
+#' in both data frames, cases are matched and filtered by identical values
+#' of `by` in `x` and `y`.
 #'
-#'   \subsection{Left- and right-joins}{
-#'     Left- and right joins usually don't add new rows (cases), but only new
-#'     columns (variables) for existing cases in `x`. For `join = "left"` or
-#'     `join = "right"` to work, `by` *must* indicate one or more columns that
-#'     are included in both data frames. For `join = "left"`, if `by` is an
-#'     identifier variable, which is included in both `x` and `y`, all variables
-#'     from `y` are copied to `x`, but only those cases from `y` that have
-#'     matching values in their identifier variable in `x` (i.e. all cases
-#'     in `x` that are also found in `y` get the related values from the new
-#'     columns in `y`). If there is no match between identifiers in `x` and `y`,
-#'     the copied variable from `y` will get a `NA` value for this particular
-#'     case. Other variables that occur both in `x` and `y`, but are not used
-#'     as identifiers (with `by`), will be renamed to avoid multiple identical
-#'     variable names. Cases in `y` where values from the identifier have no
-#'     match in `x`'s identifier are removed. `join = "right"` works in
-#'     a similar way as `join = "left"`, just that only cases from `x` that
-#'     have matching values in their identifier variable in `y` are chosen.
-#'     \cr \cr
-#'     In base R, these are equivalent to `merge(x, y, all.x = TRUE)` and
-#'     `merge(x, y, all.y = TRUE)`.
-#'   }
+#' @section Left- and right-joins:
 #'
-#'   \subsection{Full joins}{
-#'     Full joins copy all cases from `y` to `x`. For matching cases in both
-#'     data frames, values for new variables are copied from `y` to `x`. For
-#'     cases in `y` not present in `x`, these will be added as new rows to `x`.
-#'     Thus, full joins not only add new columns (variables), but also might
-#'     add new rows (cases).
-#'     \cr \cr
-#'     In base R, this is equivalent to `merge(x, y, all = TRUE)`.
-#'   }
+#' Left- and right joins usually don't add new rows (cases), but only new
+#' columns (variables) for existing cases in `x`. For `join = "left"` or
+#' `join = "right"` to work, `by` *must* indicate one or more columns that
+#' are included in both data frames. For `join = "left"`, if `by` is an
+#' identifier variable, which is included in both `x` and `y`, all variables
+#' from `y` are copied to `x`, but only those cases from `y` that have
+#' matching values in their identifier variable in `x` (i.e. all cases
+#' in `x` that are also found in `y` get the related values from the new
+#' columns in `y`). If there is no match between identifiers in `x` and `y`,
+#' the copied variable from `y` will get a `NA` value for this particular
+#' case. Other variables that occur both in `x` and `y`, but are not used
+#' as identifiers (with `by`), will be renamed to avoid multiple identical
+#' variable names. Cases in `y` where values from the identifier have no
+#' match in `x`'s identifier are removed. `join = "right"` works in
+#' a similar way as `join = "left"`, just that only cases from `x` that
+#' have matching values in their identifier variable in `y` are chosen.
 #'
-#'   \subsection{Inner joins}{
-#'     Inner joins merge two data frames, however, only those rows (cases) are
-#'     kept that are present in both data frames. Thus, inner joins usually
-#'     add new columns (variables), but also remove rows (cases) that only
-#'     occur in one data frame.
-#'     \cr \cr
-#'     In base R, this is equivalent to `merge(x, y)`.
-#'   }
+#' In base R, these are equivalent to `merge(x, y, all.x = TRUE)` and
+#' `merge(x, y, all.y = TRUE)`.
 #'
-#'   \subsection{Binds}{
-#'     `join = "bind"` row-binds the complete second data frame `y` to `x`.
-#'     Unlike simple `rbind()`, which requires the same columns for both data
-#'     frames, `join = "bind"` will bind shared columns from `y` to `x`, and
-#'     add new columns from `y` to `x`.
-#'   }
+#' @section Full joins:
+#'
+#' Full joins copy all cases from `y` to `x`. For matching cases in both
+#' data frames, values for new variables are copied from `y` to `x`. For
+#' cases in `y` not present in `x`, these will be added as new rows to `x`.
+#' Thus, full joins not only add new columns (variables), but also might
+#' add new rows (cases).
+#'
+#' In base R, this is equivalent to `merge(x, y, all = TRUE)`.
+#'
+#' @section Inner joins:
+#'
+#' Inner joins merge two data frames, however, only those rows (cases) are
+#' kept that are present in both data frames. Thus, inner joins usually
+#' add new columns (variables), but also remove rows (cases) that only
+#' occur in one data frame.
+#'
+#' In base R, this is equivalent to `merge(x, y)`.
+#'
+#' @section Binds:
+#'
+#' `join = "bind"` row-binds the complete second data frame `y` to `x`.
+#' Unlike simple `rbind()`, which requires the same columns for both data
+#' frames, `join = "bind"` will bind shared columns from `y` to `x`, and
+#' add new columns from `y` to `x`.
 #'
 #' @examples
 #'
@@ -171,19 +169,31 @@ data_join <- data_merge
 
 #' @rdname data_merge
 #' @export
-data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, verbose = TRUE, ...) {
+data_merge.data.frame <- function(
+  x,
+  y,
+  join = "left",
+  by = NULL,
+  id = NULL,
+  verbose = TRUE,
+  ...
+) {
   class_x <- class(x)
 
   # save variable attributes
   attr_x_vars <- lapply(x, attributes)
   attr_y_vars <- lapply(y, attributes)
-  attr_vars <- c(attr_x_vars, attr_y_vars[names(attr_y_vars)[!names(attr_y_vars) %in% names(attr_x_vars)]])
-
+  attr_vars <- c(
+    attr_x_vars,
+    attr_y_vars[names(attr_y_vars)[!names(attr_y_vars) %in% names(attr_x_vars)]]
+  )
 
   # check join-argument ----------------------
 
-  join <- match.arg(join, choices = c("full", "left", "right", "inner", "semi", "anti", "bind"))
-
+  join <- match.arg(
+    join,
+    choices = c("full", "left", "right", "inner", "semi", "anti", "bind")
+  )
 
   # check id-argument ----------------------
 
@@ -195,7 +205,10 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     # and also tell user...
     if (isTRUE(verbose)) {
       insight::format_warning(
-        sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)
+        sprintf(
+          "Value of `id` already exists as column name. ID column was renamed to `%s`.",
+          id
+        )
       )
     }
   }
@@ -205,7 +218,6 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     y[[id]] <- 2
   }
 
-
   # check merge columns ("by"-argument) ----------------------
 
   if (join != "bind") {
@@ -221,11 +233,17 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
       missing_in_y <- setdiff(by, colnames(y))
       stop_message <- c(
         "Not all columns specified in `by` were found in the data frames.",
-        if (length(missing_in_x) > 0) {
-          paste0("Following columns are in `by` but absent in `x`: ", text_concatenate(missing_in_x))
+        if (length(missing_in_x) > 0L) {
+          paste0(
+            "Following columns are in `by` but absent in `x`: ",
+            text_concatenate(missing_in_x)
+          )
         },
-        if (length(missing_in_y) > 0) {
-          paste0("Following columns are in `by` but absent in `y`: ", text_concatenate(missing_in_y))
+        if (length(missing_in_y) > 0L) {
+          paste0(
+            "Following columns are in `by` but absent in `y`: ",
+            text_concatenate(missing_in_y)
+          )
         }
       )
       if (isTRUE(verbose)) {
@@ -247,7 +265,6 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     }
   }
 
-
   # check valid combination of "join" and "by" -----------------------
 
   if (join %in% c("anti", "semi") && (is.null(by) || length(by) != 1)) {
@@ -259,21 +276,21 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     )
   }
 
-
   # merge --------------------
 
   # for later sorting
   if (join != "bind") {
-    if (nrow(x) > 0) {
+    if (nrow(x) > 0L) {
       x$.data_merge_id_x <- seq_len(nrow(x))
     }
-    if (nrow(y) > 0) {
+    if (nrow(y) > 0L) {
       y$.data_merge_id_y <- (seq_len(nrow(y))) + nrow(x)
     }
   }
   all_columns <- union(colnames(x), colnames(y))
 
-  out <- switch(join,
+  out <- switch(
+    join,
     full = merge(x, y, all = TRUE, sort = FALSE, by = by),
     left = merge(x, y, all.x = TRUE, sort = FALSE, by = by),
     right = merge(x, y, all.y = TRUE, sort = FALSE, by = by),
@@ -283,14 +300,15 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     bind = .bind_data_frames(x, y)
   )
 
-
   # sort rows, add attributes, and return results -------------------------
 
   if (".data_merge_id_x" %in% colnames(out)) {
     # for full joins, we have no complete sorting id, but NAs for each
     # data frame. we now "merge" the two sorting IDs from each data frame.
     if (anyNA(out$.data_merge_id_x) && ".data_merge_id_y" %in% colnames(out)) {
-      out$.data_merge_id_x[is.na(out$.data_merge_id_x)] <- out$.data_merge_id_y[is.na(out$.data_merge_id_x)]
+      out$.data_merge_id_x[is.na(
+        out$.data_merge_id_x
+      )] <- out$.data_merge_id_y[is.na(out$.data_merge_id_x)]
     }
     out <- out[order(out$.data_merge_id_x), ]
     out$.data_merge_id_x <- NULL
@@ -315,7 +333,10 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
   for (i in colnames(out)) {
     if (is.list(attr_vars[[i]])) {
       if (is.list(attributes(out[[i]]))) {
-        attributes(out[[i]]) <- utils::modifyList(attr_vars[[i]], attributes(out[[i]]))
+        attributes(out[[i]]) <- utils::modifyList(
+          attr_vars[[i]],
+          attributes(out[[i]])
+        )
       } else {
         attributes(out[[i]]) <- attr_vars[[i]]
       }
@@ -329,12 +350,27 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
 
 #' @rdname data_merge
 #' @export
-data_merge.list <- function(x, join = "left", by = NULL, id = NULL, verbose = TRUE, ...) {
+data_merge.list <- function(
+  x,
+  join = "left",
+  by = NULL,
+  id = NULL,
+  verbose = TRUE,
+  ...
+) {
   out <- x[[1]]
   df_id <- rep(1, times = nrow(out))
 
   for (i in 2:length(x)) {
-    out <- data_merge(out, x[[i]], join = join, by = by, id = NULL, verbose = verbose, ...)
+    out <- data_merge(
+      out,
+      x[[i]],
+      join = join,
+      by = by,
+      id = NULL,
+      verbose = verbose,
+      ...
+    )
     df_id <- c(df_id, rep(i, times = nrow(x[[i]])))
   }
 
@@ -342,11 +378,16 @@ data_merge.list <- function(x, join = "left", by = NULL, id = NULL, verbose = TR
   if (!is.null(id) && join == "bind") {
     if (id %in% colnames(out)) {
       # ensure unique ID
-      id <- make.unique(c(colnames(out), id), sep = "_")[length(colnames(out)) + 1]
+      id <- make.unique(c(colnames(out), id), sep = "_")[
+        length(colnames(out)) + 1
+      ]
       # and also tell user...
       if (isTRUE(verbose)) {
         insight::format_warning(
-          sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)
+          sprintf(
+            "Value of `id` already exists as column name. ID column was renamed to `%s`.",
+            id
+          )
         )
       }
     }
@@ -364,14 +405,14 @@ data_merge.list <- function(x, join = "left", by = NULL, id = NULL, verbose = TR
     out <- rbind(x, y[match(colnames(x), colnames(y))])
   } else {
     # add ID for merging
-    if (nrow(x) > 0) {
+    if (nrow(x) > 0L) {
       x$.data_merge_row <- seq_len(nrow(x))
     }
-    if (nrow(y) > 0) {
+    if (nrow(y) > 0L) {
       y$.data_merge_row <- (nrow(x) + 1):(nrow(x) + nrow(y))
     }
-    by <- intersect(colnames(x), colnames(y))
-    out <- merge(x, y, all = TRUE, sort = FALSE, by = by)
+    merge_by <- intersect(colnames(x), colnames(y))
+    out <- merge(x, y, all = TRUE, sort = FALSE, by = merge_by)
   }
 
   # for empty df's, merge() may return an empty character vector
