@@ -17,6 +17,8 @@
 #'   names.
 #' @param verbose Toggle warnings.
 #'
+#' @inherit data_rename seealso
+#'
 #' @return A (rotated) data frame.
 #'
 #' @examples
@@ -31,17 +33,18 @@
 #' data_rotate(x, colnames = TRUE)
 #' data_rotate(x, rownames = "property", colnames = TRUE)
 #'
-#' # warn that data types are changed
-#' str(data_rotate(iris[1:4, ]))
-#'
 #' # use either first column or specific column for column names
-#' x <- data.frame(a = 1:5, b = 11:15, c = letters[1:5], d = rnorm(5))
+#' x <- data.frame(a = 1:5, b = 11:15, c = 21:25)
 #' data_rotate(x, colnames = TRUE)
 #' data_rotate(x, colnames = "c")
 #'
-#' @inherit data_rename seealso
 #' @export
-data_rotate <- function(data, rownames = NULL, colnames = FALSE, verbose = TRUE) {
+data_rotate <- function(
+  data,
+  rownames = NULL,
+  colnames = FALSE,
+  verbose = TRUE
+) {
   # copy attributes
   attr_data <- attributes(data)
 
@@ -49,7 +52,9 @@ data_rotate <- function(data, rownames = NULL, colnames = FALSE, verbose = TRUE)
   if (isTRUE(colnames)) {
     colnames <- data[[1]]
     data <- data[-1]
-  } else if (!is.null(colnames) && is.character(colnames) && colnames %in% colnames(data)) {
+  } else if (
+    !is.null(colnames) && is.character(colnames) && colnames %in% colnames(data)
+  ) {
     cn_col <- which(colnames(data) == colnames)
     colnames <- data[[colnames]]
     data <- data[-cn_col]
@@ -58,10 +63,13 @@ data_rotate <- function(data, rownames = NULL, colnames = FALSE, verbose = TRUE)
   }
 
   # warning after possible removal of columns
-  if (length(unique(sapply(data, class))) > 1) {
-    if (verbose) {
-      insight::format_warning("Your data frame contains mixed types of data. After transposition, all variables will be transformed into characters.")
-    }
+  if (
+    verbose &&
+      insight::n_unique(vapply(data, typeof, FUN.VALUE = character(1L))) > 1L
+  ) {
+    insight::format_warning(
+      "Your data frame contains mixed types of data. After transposition, all variables will be transformed into characters."
+    ) # nolint
   }
 
   # rotate data frame by 90 degrees
@@ -80,7 +88,9 @@ data_rotate <- function(data, rownames = NULL, colnames = FALSE, verbose = TRUE)
   }
 
   # add rownames as a new column, if requested
-  if (!is.null(rownames)) out <- rownames_as_column(out, var = rownames)
+  if (!is.null(rownames)) {
+    out <- rownames_as_column(out, var = rownames)
+  }
 
   out <- .replace_attrs(out, attr_data)
 
