@@ -5,9 +5,9 @@
 #' data frame or a matrix.
 #'
 #' @param x A (grouped) data frame.
-#' @param by Optional character string, indicating the name of a variable in `x`.
-#' If supplied, the data will be split by this variable and summary statistics
-#' will be computed for each group.
+#' @param by Optional character string, indicating the names of one or more
+#' variables in the data frame. If supplied, the data will be split by these
+#' variables and summary statistics will be computed for each group.
 #' @param remove_na Logical. If `TRUE`, missing values are omitted from the
 #' grouping variable. If `FALSE` (default), missing values are included as a
 #' level in the grouping variable.
@@ -64,7 +64,9 @@ data_summary.matrix <- function(x, ..., by = NULL, remove_na = FALSE) {
 
 #' @export
 data_summary.default <- function(x, ...) {
-  insight::format_error("`data_summary()` only works for (grouped) data frames and matrices.")
+  insight::format_error(
+    "`data_summary()` only works for (grouped) data frames and matrices."
+  )
 }
 
 
@@ -75,7 +77,9 @@ data_summary.data.frame <- function(x, ..., by = NULL, remove_na = FALSE) {
 
   # do we have any expression at all?
   if (length(dots) == 0) {
-    insight::format_error("No expressions for calculating summary statistics provided.")
+    insight::format_error(
+      "No expressions for calculating summary statistics provided."
+    )
   }
 
   if (is.null(by)) {
@@ -86,7 +90,9 @@ data_summary.data.frame <- function(x, ..., by = NULL, remove_na = FALSE) {
   } else {
     # sanity check - is "by" a character string?
     if (!is.character(by)) {
-      insight::format_error("Argument `by` must be a character string indicating the name of variables in the data.")
+      insight::format_error(
+        "Argument `by` must be a character string indicating the name of variables in the data."
+      )
     }
     # is "by" in the data?
     if (!all(by %in% colnames(x))) {
@@ -122,7 +128,7 @@ data_summary.data.frame <- function(x, ..., by = NULL, remove_na = FALSE) {
       # bind grouping-variables and values
       summarised_data <- cbind(s[1, by], summarised_data)
       # make sure we have proper column names
-      colnames(summarised_data) <- c(by, vapply(summarise, names, character(1)))
+      colnames(summarised_data) <- c(by, unlist(lapply(summarise, names)))
       summarised_data
     })
     out <- do.call(rbind, out)
@@ -166,7 +172,9 @@ data_summary.grouped_df <- function(x, ..., by = NULL, remove_na = FALSE) {
         if (all(vapply(dots, is.character, logical(1)))) {
           dots <- list(unlist(dots))
         } else {
-          insight::format_error("You cannot mix string and literal representation of expressions.")
+          insight::format_error(
+            "You cannot mix string and literal representation of expressions."
+          )
         }
       }
       # expression is given as character string, e.g.
@@ -174,31 +182,51 @@ data_summary.grouped_df <- function(x, ..., by = NULL, remove_na = FALSE) {
       # data_summary(iris, a, by = "Species")
       # or as character vector, e.g.
       # data_summary(iris, c("var_a = mean(Sepal.Width)", "var_b = sd(Sepal.Width)"))
-      character_symbol <- tryCatch(.dynEval(dots[[1]]), error = function(e) NULL)
+      character_symbol <- tryCatch(.dynEval(dots[[1]]), error = function(e) {
+        NULL
+      })
       # do we have a character vector? Then we can proceed
       if (is.character(character_symbol)) {
         dots <- lapply(character_symbol, function(s) {
           # turn value from character vector into expression
           str2lang(.dynEval(s))
         })
-        names(dots) <- vapply(dots, function(n) insight::safe_deparse(n[[2]]), character(1))
+        names(dots) <- vapply(
+          dots,
+          function(n) insight::safe_deparse(n[[2]]),
+          character(1)
+        )
       }
     }
 
     out <- lapply(seq_along(dots), function(i) {
       new_variable <- .get_new_dots_variable(dots, i, data)
-      stats::setNames(new_variable, names(dots)[i])
+      if (inherits(new_variable, c("bayestestR_ci", "bayestestR_eti"))) {
+        stats::setNames(new_variable, c("CI", "CI_low", "CI_high"))
+      } else {
+        stats::setNames(new_variable, names(dots)[i])
+      }
     })
   }
 
   # check for correct length of output - must be a single value!
-  if (any(lengths(out) != 1)) {
+  # Exception: bayestestR::ci()
+  wrong_length <- !sapply(
+    out,
+    inherits,
+    what = c("bayestestR_ci", "bayestestR_eti")
+  ) &
+    lengths(out) != 1 # nolint
+  if (any(wrong_length)) {
     insight::format_error(
       paste0(
         "Each expression must return a single value. Following expression",
-        ifelse(sum(lengths(out) != 1) > 1, "s", " "),
+        ifelse(sum(wrong_length) > 1, "s", " "),
         " returned more than one value: ",
-        text_concatenate(vapply(dots[lengths(out) != 1], insight::safe_deparse, character(1)), enclose = "\"")
+        text_concatenate(
+          vapply(dots[wrong_length], insight::safe_deparse, character(1)),
+          enclose = "\""
+        )
       )
     )
   }
@@ -214,6 +242,11 @@ print.dw_data_summary <- function(x, ...) {
   if (nrow(x) == 0) {
     cat("No matches found.\n")
   } else {
+    if (all(c("CI", "CI_low", "CI_high") %in% colnames(x))) {
+      ci <- insight::format_table(x[c("CI", "CI_low", "CI_high")], ...)
+      x$CI <- x$CI_low <- x$CI_high <- NULL
+      x <- cbind(x, ci)
+    }
     cat(insight::export_table(x, missing = "<NA>", ...))
   }
 }
