@@ -280,15 +280,17 @@
 #' demean(dat, select = ~ a + x * y, by = ~ID)
 #'
 #' @export
-demean <- function(x,
-                   select,
-                   by,
-                   nested = FALSE,
-                   suffix_demean = "_within",
-                   suffix_groupmean = "_between",
-                   append = TRUE,
-                   add_attributes = TRUE,
-                   verbose = TRUE) {
+demean <- function(
+  x,
+  select,
+  by,
+  nested = FALSE,
+  suffix_demean = "_within",
+  suffix_groupmean = "_between",
+  append = TRUE,
+  add_attributes = TRUE,
+  verbose = TRUE
+) {
   degroup(
     x = x,
     select = select,
@@ -306,27 +308,36 @@ demean <- function(x,
 
 #' @rdname demean
 #' @export
-degroup <- function(x,
-                    select,
-                    by,
-                    nested = FALSE,
-                    center = "mean",
-                    suffix_demean = "_within",
-                    suffix_groupmean = "_between",
-                    append = TRUE,
-                    add_attributes = TRUE,
-                    verbose = TRUE) {
+degroup <- function(
+  x,
+  select,
+  by,
+  nested = FALSE,
+  center = "mean",
+  suffix_demean = "_within",
+  suffix_groupmean = "_between",
+  append = TRUE,
+  add_attributes = TRUE,
+  verbose = TRUE
+) {
   # ugly tibbles again... but save original data frame
   original_data <- x
   x <- .coerce_to_dataframe(x)
 
-  center <- match.arg(tolower(center), choices = c("mean", "median", "mode", "min", "max"))
+  center <- match.arg(
+    tolower(center),
+    choices = c("mean", "median", "mode", "min", "max")
+  )
 
   if (inherits(select, "formula")) {
     # formula to character, remove "~", split at "+". We don't use `all.vars()`
     # here because we want to keep the interaction terms as they are
     select <- trimws(unlist(
-      strsplit(gsub("~", "", insight::safe_deparse(select), fixed = TRUE), "+", fixed = TRUE),
+      strsplit(
+        gsub("~", "", insight::safe_deparse(select), fixed = TRUE),
+        "+",
+        fixed = TRUE
+      ),
       use.names = FALSE
     ))
   }
@@ -338,7 +349,10 @@ degroup <- function(x,
 
   # we also allow lme4-syntax here: if by = "L4/L3/L2", we assume a nested design
   if (length(by) == 1 && grepl("/", by, fixed = TRUE)) {
-    by <- insight::trim_ws(unlist(strsplit(by, "/", fixed = TRUE), use.names = FALSE))
+    by <- insight::trim_ws(unlist(
+      strsplit(by, "/", fixed = TRUE),
+      use.names = FALSE
+    ))
     nested <- TRUE
   }
 
@@ -349,9 +363,15 @@ degroup <- function(x,
   # if we have interaction terms that should be de-meaned, calculate the product
   # of the terms first, then demean the product
   if (length(interactions_yes)) {
-    interaction_terms <- lapply(strsplit(interactions_yes, "*", fixed = TRUE), trimws)
+    interaction_terms <- lapply(
+      strsplit(interactions_yes, "*", fixed = TRUE),
+      trimws
+    )
     product <- lapply(interaction_terms, function(i) do.call(`*`, x[, i]))
-    new_dat <- as.data.frame(stats::setNames(product, gsub("\\s", "", gsub("*", "_", interactions_yes, fixed = TRUE))))
+    new_dat <- as.data.frame(stats::setNames(
+      product,
+      gsub("\\s", "", gsub("*", "_", interactions_yes, fixed = TRUE))
+    ))
     x <- cbind(x, new_dat)
     select <- c(interactions_no, colnames(new_dat))
   }
@@ -368,16 +388,23 @@ degroup <- function(x,
         ifelse(length(not_found) > 1, " were", " was"),
         " not found in the dataset."
       ),
-      .misspelled_string(colnames(x), not_found, "Possibly misspelled or not yet defined?")
+      .misspelled_string(
+        colnames(x),
+        not_found,
+        "Possibly misspelled or not yet defined?"
+      )
     )
   }
 
   # get data to demean...
   dat <- x[, c(select, by)]
 
-
   # find categorical predictors that are coded as factors
-  categorical_predictors <- vapply(dat[select], is.factor, FUN.VALUE = logical(1L))
+  categorical_predictors <- vapply(
+    dat[select],
+    is.factor,
+    FUN.VALUE = logical(1L)
+  )
 
   # convert binary predictors to numeric
   if (any(categorical_predictors)) {
@@ -416,12 +443,12 @@ degroup <- function(x,
     }
   }
 
-
   # group variables, then calculate the mean-value
   # for variables within each group (the group means). assign
   # mean values to a vector of same length as the data
 
-  gm_fun <- switch(center,
+  gm_fun <- switch(
+    center,
     mode = function(.gm) distribution_mode(stats::na.omit(.gm)),
     median = function(.gm) stats::median(.gm, na.rm = TRUE),
     min = function(.gm) min(.gm, na.rm = TRUE),
@@ -441,7 +468,9 @@ degroup <- function(x,
     })
     names(group_means_list) <- select
     # create de-meaned variables by subtracting the group mean from each individual value
-    person_means_list <- lapply(select, function(i) dat[[i]] - group_means_list[[i]])
+    person_means_list <- lapply(select, function(i) {
+      dat[[i]] - group_means_list[[i]]
+    })
   } else if (nested) {
     # nested design: by > 1, nested is explicitly set to TRUE
     # We want:
@@ -454,14 +483,13 @@ degroup <- function(x,
     # xbar(jk) <- ave(x_ijk, L3, L2, FUN = mean), the group mean of the variable at second level
     group_means_list <- lapply(select, function(i) {
       out <- lapply(seq_along(by), function(k) {
-        dat$higher_levels <- do.call(paste, c(dat[by[1:k]], list(sep = "_")))
-        stats::ave(dat[[i]], dat$higher_levels, FUN = gm_fun)
+        stats::ave(dat[[i]], dat[, by[1:k], drop = FALSE], FUN = gm_fun)
       })
       # subtract mean of higher level from lower level
       for (j in 2:length(by)) {
         out[[j]] <- out[[j]] - out[[j - 1]]
       }
-      names(out) <- paste0(select, "_", by)
+      names(out) <- paste0(i, "_", by)
       out
     })
     # create de-meaned variables by subtracting the group mean from each individual value
@@ -470,8 +498,7 @@ degroup <- function(x,
       # function(i) dat[[select[i]]] - group_means_list[[i]][[length(by)]]
       select,
       function(i) {
-        dat$higher_levels <- do.call(paste, c(dat[by], list(sep = "_")))
-        dat[[i]] - stats::ave(dat[[i]], dat$higher_levels, FUN = gm_fun)
+        dat[[i]] - stats::ave(dat[[i]], dat[, by, drop = FALSE], FUN = gm_fun)
       }
     )
   } else {
@@ -483,11 +510,13 @@ degroup <- function(x,
       names(out) <- paste0(select, "_", j)
       out
     })
+    group_means_list <- unlist(group_means_list, recursive = FALSE)
+
     # de-meaned variables for cross-classified design is simply subtracting
     # all group means from each individual value
-    person_means_list <- lapply(seq_along(select), function(i) {
-      sum_group_means <- do.call(`+`, lapply(group_means_list, function(j) j[[i]]))
-      dat[[select[i]]] - sum_group_means
+    person_means_list <- lapply(select, function(i) {
+      sum_group_means <- Reduce("+", group_means_list[paste0(i, "_", by)])
+      dat[[i]] - sum_group_means
     })
   }
 
@@ -499,8 +528,16 @@ degroup <- function(x,
   group_means <- as.data.frame(group_means_list)
   person_means <- as.data.frame(person_means_list)
 
-  colnames(person_means) <- sprintf("%s%s", colnames(person_means), suffix_demean)
-  colnames(group_means) <- sprintf("%s%s", colnames(group_means), suffix_groupmean)
+  colnames(person_means) <- sprintf(
+    "%s%s",
+    colnames(person_means),
+    suffix_demean
+  )
+  colnames(group_means) <- sprintf(
+    "%s%s",
+    colnames(group_means),
+    suffix_groupmean
+  )
 
   if (isTRUE(add_attributes)) {
     person_means[] <- lapply(person_means, function(i) {
