@@ -16,21 +16,19 @@
 #' @references https://stats.stackexchange.com/questions/24607/how-to-measure-smoothness-of-a-time-series-in-r
 #'
 #' @export
-smoothness <- function(x,
-                       method = "cor",
-                       lag = 1,
-                       iterations = NULL,
-                       ...) {
+smoothness <- function(x, method = "cor", lag = 1, iterations = NULL, ...) {
   UseMethod("smoothness")
 }
 
 
 #' @export
-smoothness.numeric <- function(x,
-                               method = "cor",
-                               lag = 1,
-                               iterations = NULL,
-                               ...) {
+smoothness.numeric <- function(
+  x,
+  method = "cor",
+  lag = 1,
+  iterations = NULL,
+  ...
+) {
   if (lag < 1) {
     lag <- round(lag * length(x))
   }
@@ -39,7 +37,10 @@ smoothness.numeric <- function(x,
   }
 
   if (method == "cor") {
-    smooth_data <- stats::cor(utils::head(x, length(x) - lag), utils::tail(x, length(x) - lag))
+    smooth_data <- stats::cor(
+      utils::head(x, length(x) - lag),
+      utils::tail(x, length(x) - lag)
+    )
   } else {
     smooth_data <- stats::sd(diff(x, lag = lag)) / abs(mean(diff(x, lag = lag)))
   }
@@ -66,11 +67,13 @@ smoothness.numeric <- function(x,
 
 
 #' @export
-smoothness.data.frame <- function(x,
-                                  method = "cor",
-                                  lag = 1,
-                                  iterations = NULL,
-                                  ...) {
+smoothness.data.frame <- function(
+  x,
+  method = "cor",
+  lag = 1,
+  iterations = NULL,
+  ...
+) {
   .smoothness <-
     lapply(
       x,
@@ -79,18 +82,23 @@ smoothness.data.frame <- function(x,
       lag = lag,
       iterations = iterations
     )
-  .smoothness <- cbind(Parameter = names(.smoothness), do.call(rbind, .smoothness))
+  .smoothness <- cbind(
+    Parameter = names(.smoothness),
+    do.call(rbind, .smoothness)
+  )
   class(.smoothness) <- unique(c("parameters_smoothness", class(.smoothness)))
   .smoothness
 }
 
 
 #' @export
-smoothness.default <- function(x,
-                               method = "cor",
-                               lag = 1,
-                               iterations = NULL,
-                               ...) {
+smoothness.default <- function(
+  x,
+  method = "cor",
+  lag = 1,
+  iterations = NULL,
+  ...
+) {
   smoothness(
     .factor_to_numeric(x),
     method = method,
