@@ -1,6 +1,8 @@
 #' @keywords internal
 .get_model_info <- function(model, model_info = NULL, ...) {
-  if (is.null(model_info)) model_info <- insight::model_info(model)
+  if (is.null(model_info)) {
+    model_info <- insight::model_info(model)
+  }
 
   model_info
 }
@@ -14,7 +16,13 @@
 #' @keywords internal
 .is_deprecated <- function(arg, replacement) {
   insight::format_warning(
-    paste0("Argument `", arg, "` is deprecated. Please use `", replacement, "` instead.")
+    paste0(
+      "Argument `",
+      arg,
+      "` is deprecated. Please use `",
+      replacement,
+      "` instead."
+    )
   )
 }
 
@@ -47,6 +55,29 @@
 }
 
 
+#' Checks dataframes for syntactically valid column names
+#' Argument "action" can be "warning", "error", or "message".
+#'
+#' @keywords internal
+#' @noRd
+.check_dataframe_names <- function(x, action = "warning", verbose = TRUE) {
+  if (verbose && !all(colnames(x) == make.names(colnames(x), unique = TRUE))) {
+    insight::format_alert(
+      "Bad column names (e.g., with spaces) have been detected which might create issues in many functions.",
+      paste0(
+        "We recommend to rename following columns: ",
+        text_concatenate(
+          colnames(x)[colnames(x) != make.names(colnames(x), unique = TRUE)],
+          enclose = "`"
+        )
+      ),
+      "You can run `names(mydata) <- make.names(names(mydata))` or use `janitor::clean_names()` for a quick fix.", # nolint
+      type = action
+    )
+  }
+}
+
+
 #' Fuzzy grep, matches pattern that are close, but not identical
 #' @examples
 #' colnames(iris)
@@ -80,9 +111,12 @@
   # init default
   msg <- ""
   # guess the misspelled string
-  possible_strings <- unlist(lapply(searchterm, function(s) {
-    source[.fuzzy_grep(source, s)] # nolint
-  }), use.names = FALSE)
+  possible_strings <- unlist(
+    lapply(searchterm, function(s) {
+      source[.fuzzy_grep(source, s)] # nolint
+    }),
+    use.names = FALSE
+  )
   if (length(possible_strings)) {
     msg <- "Did you mean "
     if (length(possible_strings) > 1) {
@@ -94,7 +128,11 @@
         )
         possible_strings <- possible_strings[1:5]
       }
-      msg <- paste0(msg, "one of ", text_concatenate(possible_strings, enclose = "\"", last = " or "))
+      msg <- paste0(
+        msg,
+        "one of ",
+        text_concatenate(possible_strings, enclose = "\"", last = " or ")
+      )
     } else {
       msg <- paste0(msg, "\"", possible_strings, "\"")
     }
@@ -125,7 +163,7 @@
   for (nm in setdiff(names(custom_attr), names(attributes(data.frame())))) {
     attr(data, which = nm) <- custom_attr[[nm]]
   }
-  return(data)
+  data
 }
 
 
@@ -184,9 +222,11 @@
         NULL
       }
     )
-    if (is.null(model) ||
-      # prevent self reference
-      inherits(model, "parameters_model")) {
+    if (
+      is.null(model) ||
+        # prevent self reference
+        inherits(model, "parameters_model")
+    ) {
       model <- tryCatch(
         {
           get(obj_name, envir = globalenv())
@@ -201,12 +241,18 @@
 }
 
 
-#' Taken from https://github.com/coolbutuseless/gluestick [licence: MIT]
+#' Taken from https://github.com/coolbutuseless/gluestick (licence: MIT)
 #' Same functionality as `{glue}`
 #'
 #' @noRd
 #' @keywords internal
-.gluestick <- function(fmt, src = parent.frame(), open = "{", close = "}", eval = TRUE) {
+.gluestick <- function(
+  fmt,
+  src = parent.frame(),
+  open = "{",
+  close = "}",
+  eval = TRUE
+) {
   nchar_open <- nchar(open)
   nchar_close <- nchar(close)
 
@@ -246,15 +292,15 @@
 
   # Evaluate
   if (eval) {
-    args <- lapply(exprs, function(expr) {
+    fun_args <- lapply(exprs, function(expr) {
       eval(parse(text = expr), envir = src)
     })
   } else {
-    args <- unname(mget(exprs, envir = as.environment(src)))
+    fun_args <- unname(mget(exprs, envir = as.environment(src)))
   }
 
   # Create the string(s)
-  do.call(sprintf, c(list(fmt_sprintf), args))
+  do.call(sprintf, c(list(fmt_sprintf), fun_args))
 }
 
 
