@@ -11,9 +11,9 @@
 #' of `visualisation_recipe()` that control the aesthetic parameters.
 #'
 #' See the specific documentation page for your object's class:
-#'  - {[modelbased][modelbased::visualisation_recipe.estimate_predicted] (`estimate_means`, `estimate_contrasts`, `estimate_slopes`, `estimate_predicted`, `estimate_grouplevel`)}
-#'  - {[correlation][correlation::visualisation_recipe.easycor_test] (`correlation`, `cor_test`)}
 #'
+#'  - {modelbased}: <https://easystats.github.io/modelbased/reference/visualisation_recipe.estimate_predicted.html>
+#'  - {correlation}: <https://easystats.github.io/correlation/reference/visualisation_recipe.easycormatrix.html>
 #'
 #' @param x An `easystats` object.
 #' @param ... Other arguments passed to other functions.
@@ -26,16 +26,18 @@ visualisation_recipe <- function(x, ...) {
 
 #' @export
 print.visualisation_recipe <- function(x, ...) {
-  for (i in 1:length(x)) {
+  for (i in seq_along(x)) {
     l <- x[[paste0("l", i)]]
     insight::print_color(paste0("Layer ", i, "\n--------\n"), "blue")
-    insight::print_color(paste0("Geom type: ", ifelse(is.null(l$geom), "[NULL]", l$geom), "\n"), "yellow")
+    insight::print_color(
+      paste0("Geom type: ", ifelse(is.null(l$geom), "[NULL]", l$geom), "\n"),
+      "yellow"
+    )
 
-    elements <- names(l)[!sapply(l, is.null)]
+    elements <- names(l)[!vapply(l, is.null, FUN.VALUE = logical(1L))]
 
     # Loop through all elements of list
     for (element in elements[elements != "geom"]) {
-
       # Print element name
       if (element == "aes") {
         cat("aes_string(\n")
@@ -58,14 +60,18 @@ print.visualisation_recipe <- function(x, ...) {
         }
         cat(")")
       } else {
-        if (is.character(l[[element]]) || is.numeric(l[[element]]) || is.factor(l[[element]])) {
+        if (
+          is.character(l[[element]]) ||
+            is.numeric(l[[element]]) ||
+            is.factor(l[[element]])
+        ) {
           if (is.character(l[[element]])) {
             cat(paste0("'", l[[element]], "'"))
           } else {
             if (length(l[[element]]) == 1) {
               cat(l[[element]])
             } else {
-              cat(paste0("c(", paste0(l[[element]], collapse = ", "), ")"))
+              cat(paste0("c(", toString(l[[element]]), ")"))
             }
           }
         } else {
@@ -79,7 +85,6 @@ print.visualisation_recipe <- function(x, ...) {
 }
 
 
-
 #' @export
 plot.visualisation_recipe <- function(x, ...) {
   insight::check_if_installed("see")
