@@ -3,14 +3,37 @@ d <- iris[1:4, ]
 # standardize -----------------------------------------------------
 test_that("standardize.data.frame", {
   x <- standardise(d, select = c("Sepal.Length", "Sepal.Width"))
-  expect_equal(as.vector(x$Sepal.Length), as.vector(scale(d$Sepal.Length)), tolerance = 0.001)
-  expect_equal(as.vector(x$Petal.Length), as.vector(d$Petal.Length), tolerance = 0.001)
-  expect_equal(colnames(x), c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species"))
+  expect_equal(
+    as.vector(x$Sepal.Length),
+    as.vector(scale(d$Sepal.Length)),
+    tolerance = 0.001
+  )
+  expect_equal(
+    as.vector(x$Petal.Length),
+    as.vector(d$Petal.Length),
+    tolerance = 0.001
+  )
+  expect_equal(
+    colnames(x),
+    c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species")
+  )
 
   x <- standardise(d, select = c("Sepal.Length", "Sepal.Width"), append = TRUE)
-  expect_equal(as.vector(x$Sepal.Length_z), as.vector(scale(d$Sepal.Length)), tolerance = 0.001)
-  expect_equal(as.vector(x$Sepal.Length), as.vector(d$Sepal.Length), tolerance = 0.001)
-  expect_equal(as.vector(x$Petal.Length), as.vector(d$Petal.Length), tolerance = 0.001)
+  expect_equal(
+    as.vector(x$Sepal.Length_z),
+    as.vector(scale(d$Sepal.Length)),
+    tolerance = 0.001
+  )
+  expect_equal(
+    as.vector(x$Sepal.Length),
+    as.vector(d$Sepal.Length),
+    tolerance = 0.001
+  )
+  expect_equal(
+    as.vector(x$Petal.Length),
+    as.vector(d$Petal.Length),
+    tolerance = 0.001
+  )
   expect_equal(
     colnames(x),
     c(
@@ -29,7 +52,13 @@ test_that("standardize other classes", {
   d <- data.frame(
     a = 1:5,
     b = factor(letters[1:5]),
-    c = as.Date(c("2022-03-22", "2022-01-02", "2022-02-02", "2021-04-02", "2020-01-19")),
+    c = as.Date(c(
+      "2022-03-22",
+      "2022-01-02",
+      "2022-02-02",
+      "2021-04-02",
+      "2020-01-19"
+    )),
     d = c(TRUE, TRUE, FALSE, FALSE, TRUE),
     e = as.complex(1:5)
   )
@@ -51,19 +80,34 @@ test_that("standardize other classes", {
     ignore_attr = TRUE
   )
   x <- standardize(d$c)
-  expect_equal(x, as.Date(
-    c(
-      "2022-03-22",
-      "2022-01-02",
-      "2022-02-02",
-      "2021-04-02",
-      "2020-01-19"
-    )
-  ), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    x,
+    as.Date(
+      c(
+        "2022-03-22",
+        "2022-01-02",
+        "2022-02-02",
+        "2021-04-02",
+        "2020-01-19"
+      )
+    ),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   x <- standardize(d$c, force = TRUE)
-  expect_equal(as.numeric(x), c(0.76992, 0.53121, 0.62488, -0.29975, -1.62626), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    as.numeric(x),
+    c(0.76992, 0.53121, 0.62488, -0.29975, -1.62626),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   x <- standardize(d$d)
-  expect_equal(x, c(TRUE, TRUE, FALSE, FALSE, TRUE), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    x,
+    c(TRUE, TRUE, FALSE, FALSE, TRUE),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   expect_message(x <- standardize(d$d, force = TRUE))
   expect_equal(
     x,
@@ -85,17 +129,37 @@ test_that("standardize other classes", {
 # center -----------------------------------------------------
 test_that("center.data.frame", {
   x <- center(d, select = c("Sepal.Length", "Sepal.Width"))
-  expect_equal(as.vector(x$Sepal.Length), as.vector(d$Sepal.Length - mean(d$Sepal.Length)), tolerance = 0.001)
-  expect_equal(as.vector(x$Petal.Length), as.vector(d$Petal.Length), tolerance = 0.001)
-  expect_equal(colnames(x), c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species"))
-
-  x <- center(d, select = c("Sepal.Length", "Sepal.Width"), append = TRUE)
-  expect_equal(as.vector(x$Sepal.Length_c),
+  expect_equal(
+    as.vector(x$Sepal.Length),
     as.vector(d$Sepal.Length - mean(d$Sepal.Length)),
     tolerance = 0.001
   )
-  expect_equal(as.vector(x$Sepal.Length), as.vector(d$Sepal.Length), tolerance = 0.001)
-  expect_equal(as.vector(x$Petal.Length), as.vector(d$Petal.Length), tolerance = 0.001)
+  expect_equal(
+    as.vector(x$Petal.Length),
+    as.vector(d$Petal.Length),
+    tolerance = 0.001
+  )
+  expect_equal(
+    colnames(x),
+    c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width", "Species")
+  )
+
+  x <- center(d, select = c("Sepal.Length", "Sepal.Width"), append = TRUE)
+  expect_equal(
+    as.vector(x$Sepal.Length_c),
+    as.vector(d$Sepal.Length - mean(d$Sepal.Length)),
+    tolerance = 0.001
+  )
+  expect_equal(
+    as.vector(x$Sepal.Length),
+    as.vector(d$Sepal.Length),
+    tolerance = 0.001
+  )
+  expect_equal(
+    as.vector(x$Petal.Length),
+    as.vector(d$Petal.Length),
+    tolerance = 0.001
+  )
   expect_equal(
     colnames(x),
     c(
@@ -114,33 +178,69 @@ test_that("center other classes", {
   d <- data.frame(
     a = 1:5,
     b = factor(letters[1:5]),
-    c = as.Date(c("2022-03-22", "2022-01-02", "2022-02-02", "2021-04-02", "2020-01-19")),
-    d = c(TRUE, TRUE, FALSE, FALSE, TRUE),
-    e = as.complex(1:5)
-  )
-
-  x <- center(d$a)
-  expect_equal(as.numeric(x), c(-2, -1, 0, 1, 2), tolerance = 1e-3, ignore_attr = TRUE)
-  x <- center(d$b)
-  expect_equal(as.numeric(x), 1:5, tolerance = 1e-3, ignore_attr = TRUE)
-  x <- center(d$b, force = TRUE)
-  expect_equal(as.numeric(x), c(-2, -1, 0, 1, 2), tolerance = 1e-3, ignore_attr = TRUE)
-  x <- center(d$c)
-  expect_equal(x, as.Date(
-    c(
+    c = as.Date(c(
       "2022-03-22",
       "2022-01-02",
       "2022-02-02",
       "2021-04-02",
       "2020-01-19"
-    )
-  ), tolerance = 1e-3, ignore_attr = TRUE)
+    )),
+    d = c(TRUE, TRUE, FALSE, FALSE, TRUE),
+    e = as.complex(1:5)
+  )
+
+  x <- center(d$a)
+  expect_equal(
+    as.numeric(x),
+    c(-2, -1, 0, 1, 2),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
+  x <- center(d$b)
+  expect_equal(as.numeric(x), 1:5, tolerance = 1e-3, ignore_attr = TRUE)
+  x <- center(d$b, force = TRUE)
+  expect_equal(
+    as.numeric(x),
+    c(-2, -1, 0, 1, 2),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
+  x <- center(d$c)
+  expect_equal(
+    x,
+    as.Date(
+      c(
+        "2022-03-22",
+        "2022-01-02",
+        "2022-02-02",
+        "2021-04-02",
+        "2020-01-19"
+      )
+    ),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   x <- center(d$c, force = TRUE)
-  expect_equal(as.numeric(x), c(254.8, 175.8, 206.8, -99.2, -538.2), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    as.numeric(x),
+    c(254.8, 175.8, 206.8, -99.2, -538.2),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   x <- center(d$d)
-  expect_equal(x, c(TRUE, TRUE, FALSE, FALSE, TRUE), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    x,
+    c(TRUE, TRUE, FALSE, FALSE, TRUE),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   expect_message(x <- center(d$d, force = TRUE))
-  expect_equal(x, c(0.4, 0.4, -0.6, -0.6, 0.4), tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(
+    x,
+    c(0.4, 0.4, -0.6, -0.6, 0.4),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
   expect_message(x <- center(d$e))
   expect_equal(x, d$e, tolerance = 1e-3, ignore_attr = TRUE)
 })
